/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizappointmenttime.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.bizappointmenttime.entity.BizAppointmentTime;
import vip.xiaonuo.biz.modular.bizappointmenttime.param.BizAppointmentTimeAddParam;
import vip.xiaonuo.biz.modular.bizappointmenttime.param.BizAppointmentTimeEditParam;
import vip.xiaonuo.biz.modular.bizappointmenttime.param.BizAppointmentTimeIdParam;
import vip.xiaonuo.biz.modular.bizappointmenttime.param.BizAppointmentTimePageParam;
import vip.xiaonuo.biz.modular.bizappointmenttime.service.BizAppointmentTimeService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 预约时段配置控制器
 *
 * @author fanzherong
 * @date  2025/03/20 17:46
 */
@Tag(name = "预约时段配置控制器")
@RestController
@Validated
public class BizAppointmentTimeController {

    @Resource
    private BizAppointmentTimeService bizAppointmentTimeService;

    /**
     * 获取预约时段配置分页
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "获取预约时段配置分页")
    @SaCheckPermission("/biz/bizappointmenttime/page")
    @GetMapping("/biz/bizappointmenttime/page")
    public CommonResult<Page<BizAppointmentTime>> page(BizAppointmentTimePageParam bizAppointmentTimePageParam) {
        return CommonResult.data(bizAppointmentTimeService.page(bizAppointmentTimePageParam));
    }

    /**
     * 添加预约时段配置
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "添加预约时段配置")
    @CommonLog("添加预约时段配置")
    @PostMapping("/biz/bizappointmenttime/add")
    public CommonResult<String> add(@RequestBody @Valid BizAppointmentTimeAddParam bizAppointmentTimeAddParam) {
        bizAppointmentTimeService.add(bizAppointmentTimeAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑预约时段配置
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "编辑预约时段配置")
    @CommonLog("编辑预约时段配置")
    @PostMapping("/biz/bizappointmenttime/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizAppointmentTimeEditParam bizAppointmentTimeEditParam) {
        bizAppointmentTimeService.edit(bizAppointmentTimeEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除预约时段配置
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "删除预约时段配置")
    @CommonLog("删除预约时段配置")
    @PostMapping("/biz/bizappointmenttime/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   List<BizAppointmentTimeIdParam> bizAppointmentTimeIdParamList) {
        bizAppointmentTimeService.delete(bizAppointmentTimeIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取预约时段配置详情
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "获取预约时段配置详情")
    @GetMapping("/biz/bizappointmenttime/detail")
    public CommonResult<BizAppointmentTime> detail(@Valid BizAppointmentTimeIdParam bizAppointmentTimeIdParam) {
        return CommonResult.data(bizAppointmentTimeService.detail(bizAppointmentTimeIdParam));
    }

    /**
     * 获取下拉预约时段列表
     *
     * @author fanzherong
     * @date  2025/03/20 17:46
     */
    @Operation(summary = "获取下拉预约时段列表")
    @GetMapping("/biz/bizappointmenttime/getDownList")
    public CommonResult<List<BizAppointmentTime>> getDownList() {
        return CommonResult.data(bizAppointmentTimeService.getDownList());
    }
}
