/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.bizexcessconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.biz.modular.bizexcessconfig.entity.BizExcessConfig;
import vip.xiaonuo.biz.modular.bizexcessconfig.mapper.BizExcessConfigMapper;
import vip.xiaonuo.biz.modular.bizexcessconfig.param.BizExcessConfigAddParam;
import vip.xiaonuo.biz.modular.bizexcessconfig.param.BizExcessConfigEditParam;
import vip.xiaonuo.biz.modular.bizexcessconfig.param.BizExcessConfigIdParam;
import vip.xiaonuo.biz.modular.bizexcessconfig.param.BizExcessConfigPageParam;
import vip.xiaonuo.biz.modular.bizexcessconfig.service.BizExcessConfigService;

import java.util.List;

/**
 * 超限配置Service接口实现类
 *
 * @author fanzherong
 * @date  2025/03/20 16:46
 **/
@Service
public class BizExcessConfigServiceImpl extends ServiceImpl<BizExcessConfigMapper, BizExcessConfig> implements BizExcessConfigService {

    @Override
    public Page<BizExcessConfig> page(BizExcessConfigPageParam bizExcessConfigPageParam) {
        QueryWrapper<BizExcessConfig> queryWrapper = new QueryWrapper<BizExcessConfig>().checkSqlInjection();
        queryWrapper.lambda().orderByDesc(BizExcessConfig::getCreateTime);
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizExcessConfigAddParam bizExcessConfigAddParam) {
        //根据车辆轴数查询，相同的轴数不能重复创建
        long count = this.count(new QueryWrapper<BizExcessConfig>().lambda().
                eq(BizExcessConfig::getVehicleAxleNumber, bizExcessConfigAddParam.getVehicleAxleNumber()).
                eq(BizExcessConfig::getStatus,"1"));
        if(count>0){
            throw new CommonException("该轴数已经添加过超限重量！");
        }
        BizExcessConfig bizExcessConfig = BeanUtil.toBean(bizExcessConfigAddParam, BizExcessConfig.class);
        this.save(bizExcessConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizExcessConfigEditParam bizExcessConfigEditParam) {
        BizExcessConfig bizExcessConfig = this.queryEntity(bizExcessConfigEditParam.getId());
        //判断是否修改过轴数，如果修改过，则校验该轴数是否添加过超限配置
        if(bizExcessConfig.getVehicleAxleNumber()!=bizExcessConfigEditParam.getVehicleAxleNumber()){
            long count = this.count(new QueryWrapper<BizExcessConfig>().lambda().
                    eq(BizExcessConfig::getVehicleAxleNumber, bizExcessConfigEditParam.getVehicleAxleNumber()).
                    eq(BizExcessConfig::getStatus,"1"));
            if(count>0){
                throw new CommonException("该轴数已经添加过超限重量！");
            }
        }
        if(!StringUtils.equals(bizExcessConfig.getStatus(),bizExcessConfigEditParam.getStatus())){
            if(StringUtils.equals(bizExcessConfigEditParam.getStatus(),"1")){
                long count = this.count(new QueryWrapper<BizExcessConfig>().lambda().
                        eq(BizExcessConfig::getVehicleAxleNumber, bizExcessConfigEditParam.getVehicleAxleNumber()).
                        eq(BizExcessConfig::getStatus,"1"));
                if(count>0){
                    throw new CommonException("该轴数已经添加过超限重量！");
                }
            }
        }
        BeanUtil.copyProperties(bizExcessConfigEditParam, bizExcessConfig);
        this.updateById(bizExcessConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizExcessConfigIdParam> bizExcessConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizExcessConfigIdParamList, BizExcessConfigIdParam::getId));
    }

    @Override
    public BizExcessConfig detail(BizExcessConfigIdParam bizExcessConfigIdParam) {
        return this.queryEntity(bizExcessConfigIdParam.getId());
    }

    @Override
    public BizExcessConfig queryEntity(String id) {
        BizExcessConfig bizExcessConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizExcessConfig)) {
            throw new CommonException("超限配置不存在，id值为：{}", id);
        }
        return bizExcessConfig;
    }

    @Override
    public List<BizExcessConfig> getList() {
        List<BizExcessConfig> list = this.list(new QueryWrapper<BizExcessConfig>().lambda().eq(BizExcessConfig::getStatus, "1"));
        return list;
    }
}
